
# 什么是openJiuwen Studio
openJiuwen Studio提供了一站式AI Agent开发平台，为开发者提供从开发到部署的全栈解决方案。该部分采用低代码 / 零代码的可视化设计与编排工具，能让开发者快速打造和调试智能体和工作流。

openJiuwen Studio为开发者搭建了可视化低码开发Agent和工作流的能力，在本次开源版本中，其提供的核心能力包括：

  * **Agent开发与测试**：插件按需选取、工作流可视化编排，记忆的灵活配置，助力开发者快速赋予 Agent 目标业务技能，同时集成在线调试、测试与发布功能，无缝衔接开发全流程。

  * **提示词开发与调优**：提供提示词一键生成、自动优化、多版本对比测试及全生命周期版本管理功能，助力开发者快速产出高质量提示词，降低 Agent 核心能力开发门槛。

  * **工作流可视化编排**：提供拖拽式画布、丰富的节点组件与配置面板，支持 Agent 业务逻辑的可视化搭建与参数自定义。搭配单步调试、实时日志查看等能力，让复杂工作流开发更高效、更省心。

  * **技能管理**：提供统一的模型、插件与记忆管理能力，支持模型快速接入与切换、插件一键安装与更新、绑定工作流、记忆策略个性化配置，为 Agent 开发提供高效的资源支撑。


# 🚀 **快速开始**

1. 参考 [安装指导](https://www.openjiuwen.com/docs-page?path=2.%E5%AE%89%E8%A3%85%E6%8C%87%E5%AF%BC%2F%E5%BF%AB%E9%80%9F%E6%8C%87%E5%BC%95)进行安装。

2. 参考 [快速上手](https://www.openjiuwen.com/docs-page?path=3.%E5%BF%AB%E9%80%9F%E4%B8%8A%E6%89%8B)快速搭建一个智能体。

3. 如需要更进一步搭建更复杂的智能体，参考 [openJiuwen 文档地址](https://www.openjiuwen.com/docs-page?path=1.%E4%BA%A7%E5%93%81%E7%AE%80%E4%BB%8B) 中的实践教程章节搭建更复杂场景的智能体。

4. 更多信息参考官方文档地址：[openJiuwen 文档地址](https://www.openjiuwen.com/docs-page?path=1.%E4%BA%A7%E5%93%81%E7%AE%80%E4%BB%8B)。

# ⚠️ 安全提示

如需将openJiuwen服务部署在公网或不受信任的网络环境中，建议在部署前评估相关安全风险并采取必要的防护措施。

# 🔧 **主要功能**

## **工作流管理**
- ✅ 创建工作流
- ✅ 编辑工作流
- ✅ 运行工作流
- ✅ 删除工作流
- ✅ 工作流状态监控

## **AI 模型配置**
- ✅ 支持多种 AI 提供商
- ✅ 模型参数配置
- ✅ API 密钥管理
- ✅ 模型连接测试

## **工作流画布**
- ✅ 可视化工作流设计
- ✅ 节点拖拽和连接
- ✅ 实时预览
- ✅ 导入/导出功能

## **技能管理**
- ✅ 插件管理与配置
- ✅ 工作流绑定
- ✅ 记忆配置

# 🙏 **致谢**

感谢以下开源项目：

 - [FlowGram 项目](https://github.com/bytedance/flowgram.ai) 该项目具备强大的可视化工作流编排能力，本项目的工作流画布功能基于FlowGram开发。

# 📄 **许可证**

本项目采用 Apache 2.0 许可证。详见 [LICENSE](LICENSE) 文件。

# 🤝 **贡献指南**

欢迎提交 Issue 和 Pull Request！

---

**openJiuwen Studio** - 让 AI 智能体开发更简单 🚀